@@ -11,4 +11,6 @@ def remove_zip(zip_name):
         logger.log(message="ZIP file removed: " + zip_name, log_level="info", to_file=True, to_terminal=True)
         # print("ZIP file removed: " + zip_name)
     else:
-        return "ZIP not exist: " + zip_name
\ No newline at end of file
+        logger.log(message="ZIP file not exist: " + zip_name, log_level="info", to_file=True, to_terminal=True)
+        # print("ZIP file not exist: " + zip_name)
+        
\ No newline at end of file
